/******************************************************************************
 * file:  TapeNode.java
 * author:  Dirk Zitterell
 * description:  an object of this class  represents the turing machine's tape
 *****************************************************************************/

class TapeNode {

    /* variables */
    private Object content;
    private TapeNode linkedNodes[];
    
    /* constructor */
    public TapeNode (Object o, TapeNode p, TapeNode n, boolean reversed) {
	this.content = o;
	this.linkedNodes = new TapeNode[2];
	this.linkedNodes[0] = reversed ? n : p;
	this.linkedNodes[1] = reversed ? p : n;
    }
    
    /* returns the content of this node */
    public Object getContent() {
	return this.content;
    }
    
    /* sets the content of this node to o */
    public void setContent(Object o) {
	this.content = o;
    }
    
    /* returns the predecessor of this node */
    public TapeNode getPreviousNode(boolean reversed) {
	return this.linkedNodes[reversed ? 1 : 0];
    }
    
    /* sets the predecessor of this node to p */
    public void setPreviousNode(TapeNode p, boolean reversed) {
	this.linkedNodes[reversed ? 1 : 0] = p;
    }
    
    /* returns the successor of this node */
    public TapeNode getNextNode(boolean reversed) {
	return this.linkedNodes[reversed ? 0 : 1];
    }
    
    /* sets the successor of this node to n */
    public void setNextNode(TapeNode n, boolean reversed) {
	this.linkedNodes[reversed ? 0 : 1] = n;
    }
    
    /* returns the node's content as a string */
    public String toString() {
	return (String) this.content;
    }
}
